Info

Struct Info 

pub struct Info {
    pub version: Option<i32>,
    pub timestamp: Option<i64>,
    pub changeset: Option<i64>,
    pub uid: Option<i32>,
    pub user_sid: Option<u32>,
    pub visible: Option<bool>,
}
Optional metadata that may be included into each primitive.

Fields

version: Option<i32>timestamp: Option<i64>changeset: Option<i64>uid: Option<i32>user_sid: Option<u32>

String IDs

visible: Option<bool>

The visible flag is used to store history information. It indicates that the current object version has been created by a delete operation on the OSM API. When a writer sets this flag, it MUST add a required_features tag with value “HistoricalInformation” to the HeaderBlock. If this flag is not available for some object it MUST be assumed to be true if the file has the required_features tag “HistoricalInformation” set.

Implementations

Source

impl Info

pub fn version(&self) -> i32

Returns the value of version, or the default value if version is unset.

pub fn timestamp(&self) -> i64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn changeset(&self) -> i64

Returns the value of changeset, or the default value if changeset is unset.

pub fn uid(&self) -> i32

Returns the value of uid, or the default value if uid is unset.

pub fn user_sid(&self) -> u32

Returns the value of user_sid, or the default value if user_sid is unset.

pub fn visible(&self) -> bool

Returns the value of visible, or the default value if visible is unset.